@@ -3,6 +3,7 @@ import requests
 import numpy as np
 import sqlalchemy
 import psycopg2.extras
+import json
 import psycopg2.errors
 from tqdm import tqdm
 
@@ -279,3 +280,25 @@ def postgres_update_with_df_v2(df, url, db, table, update_columns, parameter_col
         print('Empty dataframe on update_with_df!')
     con.close()
 
+
+
+
+
+
+import requests
+import json
+
+
+def send_alert(body):
+
+    url = "https://hooks.slack.com/services/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"
+
+    payload = json.dumps(body)
+    headers = {
+    'Content-type': 'application/json'
+    }
+
+    response = requests.request("POST", url, headers=headers, data=payload)
+
+    response = response.text
+    return(response)
